%global desc %{expand: \
OpenVINO is an open-source toolkit for optimizing and deploying AI inference.
It can be used to develop applications and solutions based on deep learning
tasks, such as: emulation of human vision, automatic speech recognition, 
natural language processing, recommendation systems, etc.}

Name:		openvino
Version:	2023.2.0
Release:	%autorelease
Summary:	Open Visual Inference And Optimization toolkit for AI inference

License:	Apache-2.0
URL:		https://github.com/openvinotoolkit/openvino
Source0:	%url/archive/%{version}/%{name}-%{version}.tar.gz

Patch0:		openvino-fedora.patch
Patch1:		openvino-pugixml.patch

ExclusiveArch:	x86_64 aarch64

BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	onnx-devel
BuildRequires:	pugixml-devel
BuildRequires:	ShellCheck
BuildRequires:	zlib-devel
%ifarch x86_64
BuildRequires:	xbyak-devel
%endif
BuildRequires:	tbb-devel

%description
%{desc}

%package devel
Summary:	Development files for %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
applications that use %{name}.

%package auto-plugin
Summary:	%{name} auto plugin
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description auto-plugin
AUTO plugin provides a unified device that enables developers to code deep
learning applications once and deploy them anywhere.

%package auto-batch-plugin
Summary:	%{name} auto batch plugin
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description auto-batch-plugin
Auto batch plugin provides automatic batching on-the-fly to improve device
utilization by grouping inference requests together, without programming
effort from the user.

%prep
%autosetup -p1

# Remove the thirdparty deps
rm -rf thirdparty/* src/plugins/intel_cpu/thirdparty/*

%build
%cmake \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_CXX_FLAGS="%{optflags} -Wformat -Wformat-security" \
	-DENABLE_AUTO=ON \
	-DENABLE_AUTO_BATCH=ON \
	-DENABLE_HETERO=OFF \
	-DENABLE_INTEL_CPU=OFF \
	-DENABLE_MLAS_FOR_CPU=OFF \
	-DENABLE_INTEL_GNA=OFF \
	-DENABLE_INTEL_GPU=OFF \
	-DENABLE_ONEDNN_FOR_GPU=OFF \
	-DENABLE_MULTI=ON \
	-DENABLE_PROXY=ON \
	-DENABLE_TEMPLATE=ON \
	-DENABLE_OV_ONNX_FRONTEND=OFF \
	-DENABLE_OV_PADDLE_FRONTEND=OFF \
	-DENABLE_OV_IR_FRONTEND=OFF \
	-DENABLE_OV_PYTORCH_FRONTEND=OFF \
	-DENABLE_OV_TF_FRONTEND=OFF \
	-DENABLE_OV_TF_LITE_FRONTEND=OFF \
	-DENABLE_PYTHON=OFF \
	-DENABLE_GAPI_PREPROCESSING=OFF \
	-DENABLE_CPPLINT=OFF \
	-DENABLE_NCC_STYLE=OFF \
	-DENABLE_PROFILING_ITT=OFF \
	-DENABLE_SYSTEM_LIBS_DEFAULT=ON \
	-DENABLE_SYSTEM_FLATBUFFERS=ON \
	-DENABLE_SYSTEM_OPENCL=OFF \
	-DENABLE_SYSTEM_PUGIXML=ON \
	-DENABLE_SYSTEM_PROTOBUF=ON \
	-DENABLE_SYSTEM_SNAPPY=OFF \
	-DENABLE_SNAPPY_COMPRESSION=OFF \
	-DENABLE_SYSTEM_TBB=ON \
	-DENABLE_TBBBIND_2_5=OFF \
	-DTBB_LIB_INSTALL_DIR=%{_libdir} \
	-DENABLE_SAMPLES=OFF \
	-DENABLE_TESTS=OFF \
	-DBUILD_SHARED_LIBS=ON
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc CONTRIBUTING.md README.md
%{_libdir}/lib%{name}.so.%{version}
%{_libdir}/lib%{name}.so.2320
%{_libdir}/lib%{name}_c.so.%{version}
%{_libdir}/lib%{name}_c.so.2320

%files devel
%{_includedir}/ie
%{_includedir}/ngraph
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}_c.so
%{_libdir}/cmake/inferenceengine-%{version}
%{_libdir}/cmake/ngraph-%{version}
%{_libdir}/cmake/openvino-%{version}
%{_libdir}/pkgconfig/%{name}.pc

%files auto-plugin
%{_libdir}/%{name}-%{version}/lib%{name}_auto_plugin.so

%files auto-batch-plugin
%{_libdir}/%{name}-%{version}/lib%{name}_auto_batch_plugin.so

%changelog
%autochangelog
